;; Generated package description from breadcrumb.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "breadcrumb" "1.0.1.0.20260804.20" "project and imenu-based breadcrumb paths" '((emacs "28.1") (project "0.9.8")) :commit "bcf7f1d1c102f8430c017d66aeee5d12e26585a4" :url "https://elpa.gnu.org/packages/breadcrumb.html" :authors '(("João Távora" . "joaotavora@gmail.com")) :maintainer '("João Távora" . "joaotavora@gmail.com"))
